@@ -42,6 +42,7 @@
 #include <errno.h>
 #include <gio/gio.h>
 #include <gio/gunixfdlist.h>
+#include <stdatomic.h>
 #include <string.h>
 #include <sys/ioctl.h>
 #include <sys/mman.h>
@@ -54,8 +55,6 @@
 
 #include "sp-perf-counter.h"
 
-#include "util.h"
-
 /*
  * Number of pages to map for the ring buffer.  We map one additional buffer
  * at the beginning for header information to communicate with perf.
@@ -227,7 +226,7 @@ sp_perf_counter_flush (SpPerfCounter     *self,
   tail = info->tail;
   head = info->map->data_head;
 
-  read_barrier ();
+  atomic_thread_fence (memory_order_acquire);
 
   if (head < tail)
     tail = head;
@@ -292,6 +291,8 @@ sp_perf_counter_flush (SpPerfCounter     *self,
     }
 
   info->tail = tail;
+
+  atomic_thread_fence (memory_order_seq_cst);
   info->map->data_tail = tail;
 }
 
