@@ -137,7 +137,7 @@ sp_profiler_menu_button_update_label (SpProfilerMenuButton *self)
       return;
     }
 
-  str = g_strdup_printf (_("%u Processes"), n_pids);
+  str = g_strdup_printf (ngettext("%u Process", "%u Processes", n_pids), n_pids);
   gtk_label_set_label (priv->label, str);
 }
 
@@ -203,7 +203,7 @@ sp_profiler_menu_button_connect (SpProfilerMenuButton *self)
 
   add_binding (&priv->list_sensitive_binding,
                priv->profiler, "whole-system",
-               priv->processes_box, "sensitive",
+               priv->processes_box, "visible",
                G_BINDING_SYNC_CREATE | G_BINDING_INVERT_BOOLEAN);
 
   add_binding (&priv->inherit_binding,
@@ -779,7 +779,7 @@ sp_profiler_menu_button_validate_spawn (SpProfilerMenuButton *self,
 {
   SpProfilerMenuButtonPrivate *priv = sp_profiler_menu_button_get_instance_private (self);
   g_auto(GStrv) argv = NULL;
-  const gchar *icon_name = NULL;
+  g_autoptr(GError) error = NULL;
   const gchar *text;
   gint argc;
 
@@ -788,17 +788,22 @@ sp_profiler_menu_button_validate_spawn (SpProfilerMenuButton *self,
 
   text = gtk_entry_get_text (entry);
 
-  if (!g_shell_parse_argv (text, &argc, &argv, NULL))
+  if (text && *text && !g_shell_parse_argv (text, &argc, &argv, &error))
     {
-      icon_name = "dialog-warning-symbolic";
       sp_profiler_set_spawn_argv (priv->profiler, NULL);
+      g_object_set (entry,
+                    "secondary-icon-name", "dialog-warning-symbolic",
+                    "secondary-icon-tooltip-text", _("The command line arguments provided are invalid"),
+                    NULL);
     }
   else
-    sp_profiler_set_spawn_argv (priv->profiler, (const gchar * const *)argv);
-
-  gtk_entry_set_icon_from_icon_name (entry,
-                                     GTK_ENTRY_ICON_SECONDARY,
-                                     icon_name);
+    {
+      sp_profiler_set_spawn_argv (priv->profiler, (const gchar * const *)argv);
+      g_object_set (entry,
+                    "secondary-icon-name", NULL,
+                    "secondary-icon-tooltip-text", NULL,
+                    NULL);
+    }
 }
 
 static void
